@@ -27,11 +27,11 @@ class CreateMatrixAssistant : public Cantor::Assistant
 {
   public:
     CreateMatrixAssistant( QObject* parent, QList<QVariant> args );
-    ~CreateMatrixAssistant() override;
+    ~CreateMatrixAssistant() override = default;
 
-    void initActions() Q_DECL_OVERRIDE;
+    void initActions() override;
     
-    QStringList run(QWidget* parentt) Q_DECL_OVERRIDE;
+    QStringList run(QWidget* parentt) override;
     
 };
 
