@@ -71,10 +71,7 @@ void RServer::initR()
     #include "renvvars.h"
 
     for (int i = 0; R_VARS[i] != nullptr; i+= 2)
-    {
-        if (setenv(R_VARS[i], R_VARS[i+1], 1) != 0)
-            qDebug()<<"ERROR: couldn't set/replace an R environment variable";
-    }
+	    qputenv(R_VARS[i], R_VARS[i+1]);
 
     //R_SignalHandlers = 0;               // Don't let R set up its own signal handlers
 
@@ -114,9 +111,6 @@ void RServer::initR()
     }
 
     qDebug()<<"done initializing";
-
-    // FIXME: other way to search symbols, see listSymbols for details
-    listSymbols();
 }
 
 //Code from the RInside library
@@ -370,9 +364,6 @@ void RServer::runCommand(const QString& cmd, bool internal)
         showFiles(neededFiles);
 
     setStatus(Idle);
-
-    // FIXME: Calling this every evaluation is probably ugly
-    listSymbols();
 }
 
 void RServer::completeCommand(const QString& cmd)
@@ -423,7 +414,7 @@ void RServer::completeCommand(const QString& cmd)
 
 void RServer::listSymbols()
 {
-//     setStatus(RServer::Busy);
+    setStatus(RServer::Busy);
 
     QStringList vars, values, funcs;
     int errorOccurred; // TODO: error checks
@@ -438,7 +429,7 @@ void RServer::listSymbols()
 
         if (Rf_isFunction(value))
             funcs << name;
-        else
+        else if (RServerSettings::variableManagement())
         {
             int convertStatus;
             SEXP valueAsString = PROTECT(R_tryEval(lang2(install("toString"),value),nullptr,&convertStatus));
@@ -448,6 +439,8 @@ void RServer::listSymbols()
                 values << QString::fromUtf8(translateCharUTF8(asChar(valueAsString)));
             }
         }
+        else
+            vars << name;
     }
     UNPROTECT(1);
 
@@ -466,8 +459,7 @@ void RServer::listSymbols()
     UNPROTECT(1);
 
     emit symbolList(vars, values, funcs);
-
-//     setStatus(RServer::Idle);
+    setStatus(Idle);
 }
 
 void RServer::setStatus(Status status)
