@@ -19,8 +19,8 @@
  */
 #include "juliaserver.h"
 
-#include <julia/julia.h>
-#include <julia/julia_version.h>
+#include <julia.h>
+#include <julia_version.h>
 
 #include <iostream>
 #include <QFileInfo>
@@ -49,6 +49,7 @@ void JuliaServer::login(const QString &path) const
     QString dir_path = QFileInfo(path).dir().absolutePath();
     jl_init(dir_path.toLatin1().constData());
 #endif
+    jl_eval_string("import REPL;");
 }
 
 #if QT_VERSION_CHECK(JULIA_VERSION_MAJOR, JULIA_VERSION_MINOR, 0) >= QT_VERSION_CHECK(0, 7, 0)
@@ -77,6 +78,10 @@ void JuliaServer::runJuliaCommand(const QString &command)
             .arg(error.fileName()).toLatin1().constData()
     );
 
+    jl_module_t* jl_repl_module = (jl_module_t*)(jl_eval_string("REPL"));
+    jl_function_t* jl_ends_func = jl_get_function(jl_repl_module, "ends_with_semicolon");
+    bool isEndsWithSemicolon = jl_unbox_bool(jl_call1(jl_ends_func, jl_cstr_to_string(command.toStdString().c_str())));
+
     // Run command
     jl_value_t *val = static_cast<jl_value_t *>(
         jl_eval_string(command.toUtf8().constData())
@@ -101,7 +106,7 @@ void JuliaServer::runJuliaCommand(const QString &command)
         jl_call3(showerror, err_stream, ex, bt);
         jl_exception_clear();
         m_was_exception = true;
-    } else if (val) { // no exception occurred
+    } else if (val && !isEndsWithSemicolon) { // no exception occurred
         // If last result is not nothing, show it
         jl_function_t *equality = jl_get_function(jl_base_module, "==");
         jl_value_t *nothing =
@@ -158,12 +163,12 @@ bool JuliaServer::getWasException() const
 #define JL_MAIN_MODULE jl_internal_main_module
 #endif
 
-void JuliaServer::parseModules()
+void JuliaServer::parseModules(bool variableManagement)
 {
-    parseJlModule(JL_MAIN_MODULE);
+    parseJlModule(JL_MAIN_MODULE, variableManagement);
 }
 
-void JuliaServer::parseJlModule(jl_module_t* module)
+void JuliaServer::parseJlModule(jl_module_t* module, bool parseValue)
 {
     jl_function_t* jl_string_function = jl_get_function(jl_base_module, "string");
 
@@ -193,7 +198,7 @@ void JuliaServer::parseJlModule(jl_module_t* module)
             if (jl_is_module(value))
             {
                 if (module == JL_MAIN_MODULE && (jl_module_t*)value != JL_MAIN_MODULE)
-                    parseJlModule((jl_module_t*)value);
+                    parseJlModule((jl_module_t*)value, parseValue);
             }
             // Function
             else if (type.startsWith(QLatin1String("#")) || type == QLatin1String("Function"))
@@ -206,16 +211,24 @@ void JuliaServer::parseJlModule(jl_module_t* module)
             {
                 if (module == JL_MAIN_MODULE && !INTERNAL_VARIABLES.contains(name))
                 {
-                    const QString& valueString = fromJuliaString(jl_call1(jl_string_function, value));
-                    if (m_variables.contains(name))
+                    if (parseValue)
                     {
-                        int i = m_variables.indexOf(name);
-                        m_variableValues[i] = valueString;
+                        const QString& valueString = fromJuliaString(jl_call1(jl_string_function, value));
+                        if (m_variables.contains(name))
+                        {
+                            int i = m_variables.indexOf(name);
+                            m_variableValues[i] = valueString;
+                        }
+                        else
+                        {
+                            m_variables.append(name);
+                            m_variableValues.append(valueString);
+                        }
                     }
                     else
                     {
-                        m_variables.append(name);
-                        m_variableValues.append(valueString);
+                        if (!m_variables.contains(name))
+                            m_variables.append(name);
                     }
                 }
             }
