@@ -90,8 +90,12 @@ bool MaximaBackend::requirementsFullfilled() const
 
 QUrl MaximaBackend::helpUrl() const
 {
-    return QUrl(i18nc("the url to the documentation of Maxima, please check if there is a translated version and use the correct url",
-                 "http://maxima.sourceforge.net/docs/manual/en/maxima.html"));
+    const QUrl& localDoc = MaximaSettings::self()->localDoc();
+    if (!localDoc.isEmpty())
+        return localDoc;
+    else
+        return QUrl(i18nc("the url to the documentation of Maxima, please check if there is a translated version and use the correct url",
+            "http://maxima.sourceforge.net/docs/manual/en/maxima.html"));
 }
 
 QWidget* MaximaBackend::settingsWidget(QWidget* parent) const
