@@ -28,21 +28,19 @@ NullSession::NullSession( Cantor::Backend* backend) : Session(backend)
 {
 }
 
-NullSession::~NullSession()
-{
-}
-
 void NullSession::login()
 {
     qDebug()<<"login";
     emit loginStarted();
-    changeStatus(Cantor::Session::Done);
+    changeStatus(Session::Done);
     emit loginDone();
 }
 
 void NullSession::logout()
 {
     qDebug()<<"logout";
+
+    changeStatus(Status::Disable);
 }
 
 void NullSession::interrupt()
@@ -54,10 +52,10 @@ void NullSession::interrupt()
     changeStatus(Cantor::Session::Done);
 }
 
-Cantor::Expression* NullSession::evaluateExpression(const QString& cmd, Cantor::Expression::FinishingBehavior behave)
+Cantor::Expression* NullSession::evaluateExpression(const QString& cmd, Cantor::Expression::FinishingBehavior behave, bool internal)
 {
     qDebug()<<"evaluating: "<<cmd;
-    NullExpression* expr=new NullExpression(this);
+    NullExpression* expr=new NullExpression(this, internal);
     expr->setFinishingBehavior(behave);
     connect(expr, &NullExpression::statusChanged, this, &NullSession::expressionFinished);
     expr->setCommand(cmd);
