@@ -52,7 +52,13 @@ QString OctaveBackend::version() const
 
 Cantor::Backend::Capabilities OctaveBackend::capabilities() const
 {
-    return SyntaxHighlighting | Completion | SyntaxHelp | VariableManagement;
+    Cantor::Backend::Capabilities cap=
+        SyntaxHighlighting|
+        Completion |
+        SyntaxHelp;
+    if (OctaveSettings::self()->variableManagement())
+        cap |= VariableManagement;
+    return cap;
 }
 
 Cantor::Session* OctaveBackend::createSession()
@@ -67,8 +73,12 @@ bool OctaveBackend::requirementsFullfilled() const
 
 QUrl OctaveBackend::helpUrl() const
 {
-    return QUrl(i18nc("the url to the documentation of Octave, please check if there is a translated version (currently Czech and Japanese) and use the correct url",
-    "http://www.gnu.org/software/octave/doc/interpreter/"));
+    const QUrl& localDoc = OctaveSettings::self()->localDoc();
+    if (!localDoc.isEmpty())
+        return localDoc;
+    else
+        return QUrl(i18nc("the url to the documentation of Octave, please check if there is a translated version (currently Czech and Japanese) and use the correct url",
+            "http://www.gnu.org/software/octave/doc/interpreter/"));
 }
 
 QString OctaveBackend::description() const
