@@ -26,7 +26,7 @@
 #include <QDebug>
 #include <QWidget>
 
-PythonBackend::PythonBackend(QObject* parent, const QList<QVariant> args) : Cantor::Backend(parent, args)
+PythonBackend::PythonBackend(QObject* parent, const QList<QVariant>& args) : Cantor::Backend(parent, args)
 {
     qDebug()<<"Creating PythonBackend";
 
@@ -42,16 +42,6 @@ PythonBackend::~PythonBackend()
     qDebug()<<"Destroying PythonBackend";
 }
 
-Cantor::Backend::Capabilities PythonBackend::capabilities() const
-{
-    qDebug()<<"Requesting capabilities of PythonSession";
-
-    return Cantor::Backend::SyntaxHighlighting |
-           Cantor::Backend::Completion         |
-           Cantor::Backend::SyntaxHelp         |
-           Cantor::Backend::VariableManagement;
-}
-
 QWidget* PythonBackend::settingsWidget(QWidget* parent) const
 {
     QWidget* widget=new QWidget(parent);
