@@ -20,24 +20,24 @@
 
 #include "scilabhighlighter.h"
 #include "scilabkeywords.h"
+#include "result.h"
+#include "textresult.h"
+#include "session.h"
 
 #include <QTextEdit>
 #include <QDebug>
 
-ScilabHighlighter::ScilabHighlighter(QObject* parent) : Cantor::DefaultHighlighter(parent)
+ScilabHighlighter::ScilabHighlighter(QObject* parent, Cantor::Session* session) : Cantor::DefaultHighlighter(parent), m_session(session)
 {
-    qDebug() << "ScilabHighlighter construtor";
-    addRule(QRegExp(QLatin1String("\\b[A-Za-z0-9_]+(?=\\()")), functionFormat());
-
-    //Code highlighting the different keywords
     addKeywords(ScilabKeywords::instance()->keywords());
+    addFunctions(ScilabKeywords::instance()->functions());
+    addVariables(ScilabKeywords::instance()->variables());
+
+    addRule(QRegExp(QLatin1String("\\b[A-Za-z0-9_]+(?=\\()")), functionFormat());
 
     addRule(QLatin1String("FIXME"), commentFormat());
     addRule(QLatin1String("TODO"), commentFormat());
 
-    addFunctions(ScilabKeywords::instance()->functions());
-    addVariables(ScilabKeywords::instance()->variables());
-
     addRule(QRegExp(QLatin1String("\"[^\"]*\"")), stringFormat());
     addRule(QRegExp(QLatin1String("'[^']*'")), stringFormat());
     addRule(QRegExp(QLatin1String("//[^\n]*")), commentFormat());
@@ -46,17 +46,9 @@ ScilabHighlighter::ScilabHighlighter(QObject* parent) : Cantor::DefaultHighlight
     commentEndExpression = QRegExp(QLatin1String("\\*/"));
 }
 
-ScilabHighlighter::~ScilabHighlighter()
-{
-}
-
 void ScilabHighlighter::highlightBlock(const QString& text)
 {
-    qDebug() << "ScilabHighlighter::highlightBlock";
-    qDebug() << "text: " << text;
-
     if (skipHighlighting(text)){
-        qDebug() << "skipHighlighting(" << text << " ) " << "== true";
         return;
     }
 
@@ -86,24 +78,7 @@ void ScilabHighlighter::highlightBlock(const QString& text)
     }
 }
 
-void ScilabHighlighter::addVariableHighlight()
-{
-    addVariables(ScilabKeywords::instance()->variables());
-    rehighlight();
-}
-
-void ScilabHighlighter::updateHighlight()
-{
-
-    addVariables(ScilabKeywords::instance()->variables());
-    addKeywords(ScilabKeywords::instance()->keywords());
-    addFunctions(ScilabKeywords::instance()->functions());
-
-    rehighlight();
-}
-
 QString ScilabHighlighter::nonSeparatingCharacters() const
 {
-    qDebug() << "ScilabHighlighter::nonSeparatingCharacters() function";
     return QLatin1String("[%]");
 }
