@@ -22,6 +22,7 @@
 #define _SESSION_H
 
 #include <QObject>
+#include <QStandardPaths>
 
 #include "cantor_export.h"
 
@@ -242,6 +243,12 @@ class CANTOR_EXPORT Session : public QObject
      */
     void setVariableModel(DefaultVariableModel* model);
 
+    /**
+     * Search file for session in AppDataLocation and in GenericDataLocation
+     */
+    QString locateCantorFile(const QString& partialPath, QStandardPaths::LocateOptions options = QStandardPaths::LocateFile);
+    QStringList locateAllCantorFiles(const QString& partialPath, QStandardPaths::LocateOptions options = QStandardPaths::LocateFile);
+
 Q_SIGNALS:
     void statusChanged(Cantor::Session::Status newStatus);
     void loginStarted();
