@@ -22,6 +22,7 @@
 #include "textresultitem.h"
 #include "imageresultitem.h"
 #include "animationresultitem.h"
+#include "commandentry.h"
 #include "worksheetentry.h"
 
 #include "lib/result.h"
@@ -37,11 +38,8 @@
 #include <KLocalizedString>
 #include <QDebug>
 
-ResultItem::ResultItem()
-{
-}
-
-ResultItem::~ResultItem()
+ResultItem::ResultItem(Cantor::Result* result):
+    m_result(result)
 {
 }
 
@@ -51,22 +49,16 @@ ResultItem* ResultItem::create(WorksheetEntry* parent, Cantor::Result* result)
     case Cantor::TextResult::Type:
     case Cantor::LatexResult::Type:
         {
-            TextResultItem* item = new TextResultItem(parent);
-            item->updateFromResult(result);
-            return item;
+            return new TextResultItem(parent, result);
         }
     case Cantor::ImageResult::Type:
     case Cantor::EpsResult::Type:
         {
-            ImageResultItem* item = new ImageResultItem(parent);
-            item->updateFromResult(result);
-            return item;
+            return new ImageResultItem(parent, result);
         }
     case Cantor::AnimationResult::Type:
         {
-            AnimationResultItem* item = new AnimationResultItem(parent);
-            item->updateFromResult(result);
-            return item;
+            return new AnimationResultItem(parent, result);
         }
     default:
         return nullptr;
@@ -76,11 +68,27 @@ ResultItem* ResultItem::create(WorksheetEntry* parent, Cantor::Result* result)
 void ResultItem::addCommonActions(QObject* self, QMenu* menu)
 {
     menu->addAction(i18n("Save result"), self, SLOT(saveResult()));
-    menu->addAction(QIcon::fromTheme(QLatin1String("edit-delete")), i18n("Remove result"),
-                    self, SIGNAL(removeResult()));
+    menu->addAction(QIcon::fromTheme(QLatin1String("edit-delete")), i18n("Remove result"), self, [this](){
+        this->needRemove();
+    });
 }
 
 QGraphicsObject* ResultItem::graphicsObject()
 {
     return dynamic_cast<QGraphicsObject*>(this);
 }
+
+CommandEntry* ResultItem::parentEntry()
+{
+    return qobject_cast<CommandEntry*>(graphicsObject()->parentObject());
+}
+
+Cantor::Result* ResultItem::result()
+{
+    return m_result;
+}
+
+void ResultItem::needRemove()
+{
+    parentEntry()->removeResult(m_result);
+}
